@@ -51,15 +51,22 @@ pub struct LogMetadataImpl {
     task_tracker: TaskTracker,
     logs_dir: PathBuf,
     node_name: String,
+    authorizer: Authorizer,
 }
 
 impl LogMetadataImpl {
-    pub fn new(ctx: CancellationToken, task_tracker: TaskTracker, logs_dir: PathBuf) -> Self {
+    pub fn new(
+        ctx: CancellationToken,
+        task_tracker: TaskTracker,
+        logs_dir: PathBuf,
+        authorizer: Authorizer,
+    ) -> Self {
         Self {
             ctx,
             task_tracker,
             logs_dir,
             node_name: env::var("NODE_NAME").unwrap_or_else(|_| "Env variable not set".to_owned()),
+            authorizer,
         }
     }
 
@@ -120,7 +127,7 @@ impl LogMetadataService for LogMetadataImpl {
         &self,
         request: Request<LogMetadataListRequest>,
     ) -> Result<Response<LogMetadataList>, Status> {
-        let authorizer = Authorizer::new(request.metadata()).await?;
+        let request_metadata = request.metadata().clone();
         let request = request.into_inner();
 
         if !self.logs_dir.is_dir() {
@@ -139,7 +146,9 @@ impl LogMetadataService for LogMetadataImpl {
             .filter(|namespace| !namespace.is_empty())
             .collect();
 
-        authorizer.is_authorized(&namespaces, "list").await?;
+        self.authorizer
+            .is_authorized(&request_metadata, &namespaces, "list")
+            .await?;
 
         let mut files = ReadDirStream::new(read_dir(&self.logs_dir).await?);
 
@@ -196,7 +205,7 @@ impl LogMetadataService for LogMetadataImpl {
         &self,
         request: Request<LogMetadataWatchRequest>,
     ) -> Result<Response<Self::WatchStream>, Status> {
-        let authorizer = Authorizer::new(request.metadata()).await?;
+        let request_metadata = request.metadata().clone();
         let request = request.into_inner();
 
         let namespaces: Vec<String> = request
@@ -205,7 +214,9 @@ impl LogMetadataService for LogMetadataImpl {
             .filter(|namespace| !namespace.is_empty())
             .collect();
 
-        authorizer.is_authorized(&namespaces, "watch").await?;
+        self.authorizer
+            .is_authorized(&request_metadata, &namespaces, "watch")
+            .await?;
 
         let (log_metadata_watcher, log_metadata_rx) = LogMetadataWatcher::new(
             self.ctx.child_token(),
@@ -224,6 +235,7 @@ impl LogMetadataService for LogMetadataImpl {
 
 #[cfg(test)]
 mod test {
+    use crate::authorizer::Authorizer;
     use crate::log_metadata::LogMetadataImpl;
     use serial_test::parallel;
     use std::io::Write;
@@ -253,13 +265,14 @@ mod test {
     async fn test_single_file_is_returned() {
         let file = create_test_file("pod-name_single-namespace_container-name-containerid", 4);
         let logs_dir = file.path().parent().unwrap().to_path_buf();
+        let authorizer = Authorizer::new().await.unwrap();
 
-        let metadata_service = LogMetadataImpl {
-            ctx: CancellationToken::new(),
-            task_tracker: TaskTracker::new(),
+        let metadata_service = LogMetadataImpl::new(
+            CancellationToken::new(),
+            TaskTracker::new(),
             logs_dir,
-            node_name: "Node name".to_owned(),
-        };
+            authorizer,
+        );
 
         let mut result = metadata_service
             .list(Request::new(LogMetadataListRequest {
@@ -308,13 +321,14 @@ mod test {
             4,
         );
         let logs_dir = third_file.path().parent().unwrap().to_path_buf();
+        let authorizer = Authorizer::new().await.unwrap();
 
-        let metadata_service = LogMetadataImpl {
-            ctx: CancellationToken::new(),
-            task_tracker: TaskTracker::new(),
+        let metadata_service = LogMetadataImpl::new(
+            CancellationToken::new(),
+            TaskTracker::new(),
             logs_dir,
-            node_name: "Node name".to_owned(),
-        };
+            authorizer,
+        );
 
         let mut result = metadata_service
             .list(Request::new(LogMetadataListRequest {
@@ -371,13 +385,14 @@ mod test {
         );
 
         let logs_dir = first_file.path().parent().unwrap().to_path_buf();
+        let authorizer = Authorizer::new().await.unwrap();
 
-        let metadata_service = LogMetadataImpl {
-            ctx: CancellationToken::new(),
-            task_tracker: TaskTracker::new(),
+        let metadata_service = LogMetadataImpl::new(
+            CancellationToken::new(),
+            TaskTracker::new(),
             logs_dir,
-            node_name: "Node name".to_owned(),
-        };
+            authorizer,
+        );
 
         let result = metadata_service
             .list(Request::new(LogMetadataListRequest {
