@@ -38,10 +38,13 @@ import (
 	"k8s.io/klog/v2"
 
 	"github.com/kubetail-org/kubetail/modules/dashboard/pkg/app"
-	"github.com/kubetail-org/kubetail/modules/shared/config"
+	dashcfg "github.com/kubetail-org/kubetail/modules/dashboard/pkg/config"
+	sharedcfg "github.com/kubetail-org/kubetail/modules/shared/config"
 	"github.com/kubetail-org/kubetail/modules/shared/k8shelpers"
+	"github.com/kubetail-org/kubetail/modules/shared/logging"
 
 	"github.com/kubetail-org/kubetail/modules/cli/internal/tunnel"
+	"github.com/kubetail-org/kubetail/modules/cli/pkg/config"
 )
 
 type serveOptions struct {
@@ -91,13 +94,6 @@ var serveCmd = &cobra.Command{
 		// set gin mode
 		gin.SetMode("release")
 
-		// configure logger
-		config.ConfigureLogger(config.LoggerOptions{
-			Enabled: true,
-			Level:   cfg.Dashboard.Logging.Level,
-			Format:  "cli",
-		})
-
 		// Capture unhandled kubernetes client errors
 		k8sruntime.ErrorHandlers = []k8sruntime.ErrorHandler{func(ctx context.Context, err error, msg string, keysAndValues ...any) {
 			// Suppress for now
@@ -123,7 +119,7 @@ var serveCmd = &cobra.Command{
 
 		// create server
 		server := http.Server{
-			Addr:         cfg.Dashboard.Addr,
+			Addr:         cfg.Addr,
 			Handler:      app,
 			IdleTimeout:  1 * time.Minute,
 			ReadTimeout:  5 * time.Second,
@@ -216,7 +212,7 @@ var serveCmd = &cobra.Command{
 	},
 }
 
-func loadServerConfig(cmd *cobra.Command) (*config.Config, *serveOptions, error) {
+func loadServerConfig(cmd *cobra.Command) (*dashcfg.Config, *serveOptions, error) {
 	// Get flags
 	configPath, _ := cmd.Flags().GetString("config")
 	test, _ := cmd.Flags().GetBool("test")
@@ -225,6 +221,12 @@ func loadServerConfig(cmd *cobra.Command) (*config.Config, *serveOptions, error)
 	remote := false
 	inCluster, _ := cmd.Flags().GetBool(InClusterFlag)
 
+	logging.ConfigureLogger(logging.LoggerOptions{
+		Enabled: true,
+		Level:   logLevel,
+		Format:  "cli",
+	})
+
 	// Init viper
 	v := viper.New()
 
@@ -232,32 +234,33 @@ func loadServerConfig(cmd *cobra.Command) (*config.Config, *serveOptions, error)
 	v.BindPFlag("commands.serve.port", cmd.Flags().Lookup("port"))
 	v.BindPFlag("commands.serve.host", cmd.Flags().Lookup("host"))
 	v.BindPFlag("commands.serve.skip-open", cmd.Flags().Lookup("skip-open"))
-	// init config
-	cliCfg, err := config.NewCLIConfigFromViper(v, configPath)
+
+	// Init config
+	cfg, err := config.NewConfig(configPath, v)
 	if err != nil {
 		return nil, nil, err
 	}
 
-	cfg := config.DefaultConfig()
+	dashCfg := dashcfg.DefaultConfig()
 
-	cfg.KubeconfigPath = cliCfg.General.KubeconfigPath
-	cfg.Dashboard.Addr = fmt.Sprintf("%s:%d", cliCfg.Commands.Serve.Host, cliCfg.Commands.Serve.Port)
-	cfg.Dashboard.Environment = config.EnvironmentDesktop
-	cfg.Dashboard.Logging.Level = logLevel
+	dashCfg.KubeconfigPath = cfg.General.KubeconfigPath
+	dashCfg.Addr = fmt.Sprintf("%s:%d", cfg.Commands.Serve.Host, cfg.Commands.Serve.Port)
+	dashCfg.Environment = sharedcfg.EnvironmentDesktop
+	dashCfg.Logging.Level = logLevel
 	if inCluster {
-		cfg.Dashboard.Environment = config.EnvironmentCluster
+		dashCfg.Environment = sharedcfg.EnvironmentCluster
 	}
-	cfg.Dashboard.Logging.AccessLog.Enabled = false
+	dashCfg.Logging.AccessLog.Enabled = false
 
 	serveOptions := &serveOptions{
-		port:     cliCfg.Commands.Serve.Port,
-		host:     cliCfg.Commands.Serve.Host,
-		skipOpen: cliCfg.Commands.Serve.SkipOpen,
+		port:     cfg.Commands.Serve.Port,
+		host:     cfg.Commands.Serve.Host,
+		skipOpen: cfg.Commands.Serve.SkipOpen,
 		remote:   remote,
 		test:     test,
 	}
 
-	return cfg, serveOptions, nil
+	return dashCfg, serveOptions, nil
 }
 
 func serveRemote(kubeconfigPath string, localPort int, skipOpen bool) {
