@@ -27,13 +27,14 @@ import (
 
 	grpcdispatcher "github.com/kubetail-org/grpc-dispatcher-go"
 
-	"github.com/kubetail-org/kubetail/modules/shared/config"
+	sharedcfg "github.com/kubetail-org/kubetail/modules/shared/config"
 	"github.com/kubetail-org/kubetail/modules/shared/ginhelpers"
 	"github.com/kubetail-org/kubetail/modules/shared/k8shelpers"
 	"github.com/kubetail-org/kubetail/modules/shared/middleware"
 
 	clusterapi "github.com/kubetail-org/kubetail/modules/cluster-api"
 	"github.com/kubetail-org/kubetail/modules/cluster-api/graph"
+	"github.com/kubetail-org/kubetail/modules/cluster-api/pkg/config"
 )
 
 type App struct {
@@ -71,7 +72,7 @@ func NewApp(cfg *config.Config) (*App, error) {
 		app.Use(gin.Recovery())
 
 		// Init connection manager
-		cm, err := k8shelpers.NewConnectionManager(config.EnvironmentCluster)
+		cm, err := k8shelpers.NewConnectionManager(sharedcfg.EnvironmentCluster)
 		if err != nil {
 			return nil, err
 		}
@@ -85,8 +86,8 @@ func NewApp(cfg *config.Config) (*App, error) {
 	app.Use(requestid.New())
 
 	// Add logging middleware
-	if cfg.ClusterAPI.Logging.AccessLog.Enabled {
-		app.Use(middleware.LoggingMiddleware(cfg.ClusterAPI.Logging.AccessLog.HideHealthChecks))
+	if cfg.Logging.AccessLog.Enabled {
+		app.Use(middleware.LoggingMiddleware(cfg.Logging.AccessLog.HideHealthChecks))
 	}
 
 	// Gzip middleware
@@ -101,7 +102,7 @@ func NewApp(cfg *config.Config) (*App, error) {
 	))
 
 	// Routes
-	root := app.Group(cfg.ClusterAPI.BasePath)
+	root := app.Group(cfg.BasePath)
 
 	// Dynamic routes
 	dynamicRoutes := root.Group("/")
