@@ -19,7 +19,7 @@ import (
 
 	"github.com/gin-gonic/gin"
 
-	"github.com/kubetail-org/kubetail/modules/shared/config"
+	"github.com/kubetail-org/kubetail/modules/cluster-api/pkg/config"
 )
 
 func init() {
@@ -28,11 +28,11 @@ func init() {
 
 // Create new base config for testing
 func NewTestConfig() *config.Config {
-	cfg := config.Config{}
-	cfg.ClusterAPI.BasePath = "/"
-	cfg.ClusterAPI.Logging.AccessLog.Enabled = false
-	cfg.ClusterAPI.CSRF.Enabled = false
-	return &cfg
+	cfg := config.DefaultConfig()
+	cfg.BasePath = "/"
+	cfg.Logging.AccessLog.Enabled = false
+	cfg.CSRF.Enabled = false
+	return cfg
 }
 
 // Create new app for testing
