@@ -20,7 +20,8 @@ import (
 	"testing"
 	"time"
 
-	"github.com/kubetail-org/kubetail/modules/shared/config"
+	"github.com/kubetail-org/kubetail/modules/dashboard/pkg/config"
+	sharedcfg "github.com/kubetail-org/kubetail/modules/shared/config"
 	k8shelpersmock "github.com/kubetail-org/kubetail/modules/shared/k8shelpers/mock"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
@@ -80,25 +81,25 @@ func createMockStatusChannelWithContext(ctx context.Context, initialStatus Healt
 func TestNewHealthMonitor(t *testing.T) {
 	tests := []struct {
 		name        string
-		environment config.Environment
+		environment sharedcfg.Environment
 		endpoint    string
 		want        interface{}
 	}{
 		{
 			name:        "Desktop environment",
-			environment: config.EnvironmentDesktop,
+			environment: sharedcfg.EnvironmentDesktop,
 			endpoint:    "",
 			want:        &DesktopHealthMonitor{},
 		},
 		{
 			name:        "Cluster environment",
-			environment: config.EnvironmentCluster,
+			environment: sharedcfg.EnvironmentCluster,
 			endpoint:    "",
 			want:        &InClusterHealthMonitor{},
 		},
 		{
 			name:        "Cluster environment with endpoint",
-			environment: config.EnvironmentCluster,
+			environment: sharedcfg.EnvironmentCluster,
 			endpoint:    "kubetail-cluster-api.kubetail-system.svc.cluster.local:50051",
 			want:        &InClusterHealthMonitor{},
 		},
@@ -110,9 +111,9 @@ func TestNewHealthMonitor(t *testing.T) {
 
 			// create config
 			cfg := config.DefaultConfig()
-			cfg.Dashboard.Environment = tt.environment
+			cfg.Environment = tt.environment
 			if tt.endpoint != "" {
-				cfg.Dashboard.ClusterAPIEndpoint = tt.endpoint
+				cfg.ClusterAPIEndpoint = tt.endpoint
 			}
 
 			// create health monitor
@@ -135,7 +136,7 @@ func TestNewHealthMonitor_InvalidEnvironment(t *testing.T) {
 
 	// create config
 	cfg := config.DefaultConfig()
-	cfg.Dashboard.Environment = "invalid"
+	cfg.Environment = "invalid"
 
 	// Assert panic
 	assert.Panics(t, func() {
