@@ -26,7 +26,7 @@ import (
 	authv1 "k8s.io/api/authentication/v1"
 	"k8s.io/utils/ptr"
 
-	"github.com/kubetail-org/kubetail/modules/shared/config"
+	"github.com/kubetail-org/kubetail/modules/dashboard/pkg/config"
 	"github.com/kubetail-org/kubetail/modules/shared/testutils"
 )
 
@@ -166,7 +166,7 @@ func (suite *authTestSuite) TestSessionGET() {
 		suite.Run(tt.name, func() {
 			// Init config
 			cfg := newTestConfig()
-			cfg.Dashboard.AuthMode = tt.setAuthMode
+			cfg.AuthMode = tt.setAuthMode
 
 			// Init app
 			app := newTestApp(cfg)
